==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/storagecache/kotlin/inputs/NamespaceJunctionArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.storagecache.kotlin.inputs

import com.pulumi.azurenative.storagecache.inputs.NamespaceJunctionArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * A namespace junction.
 * @property namespacePath Namespace path on a cache for a Storage Target.
 * @property nfsAccessPolicy Name of the access policy applied to this junction.
 * @property nfsExport NFS export where targetPath exists.
 * @property targetPath Path in Storage Target to which namespacePath points.
 */
public data class NamespaceJunctionArgs(
    public val namespacePath: Output<String>? = null,
    public val nfsAccessPolicy: Output<String>? = null,
    public val nfsExport: Output<String>? = null,
    public val targetPath: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.storagecache.inputs.NamespaceJunctionArgs> {
    override fun toJava(): com.pulumi.azurenative.storagecache.inputs.NamespaceJunctionArgs =
        com.pulumi.azurenative.storagecache.inputs.NamespaceJunctionArgs.builder()
            .namespacePath(namespacePath?.applyValue({ args0 -> args0 }))
            .nfsAccessPolicy(nfsAccessPolicy?.applyValue({ args0 -> args0 }))
            .nfsExport(nfsExport?.applyValue({ args0 -> args0 }))
            .targetPath(targetPath?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [NamespaceJunctionArgs].
 */
@PulumiTagMarker
public class NamespaceJunctionArgsBuilder internal constructor() {
    private var namespacePath: Output<String>? = null

    private var nfsAccessPolicy: Output<String>? = null

    private var nfsExport: Output<String>? = null

    private var targetPath: Output<String>? = null

    /**
     * @param value Namespace path on a cache for a Storage Target.
     */
    @JvmName("eldrplvvdeknyfre")
    public suspend fun namespacePath(`value`: Output<String>) {
        this.namespacePath = value
    }

    /**
     * @param value Name of the access policy applied to this junction.
     */
    @JvmName("nlkkkukoddtkhukb")
    public suspend fun nfsAccessPolicy(`value`: Output<String>) {
        this.nfsAccessPolicy = value
    }

    /**
     * @param value NFS export where targetPath exists.
     */
    @JvmName("bjowralqdmpuixmu")
    public suspend fun nfsExport(`value`: Output<String>) {
        this.nfsExport = value
    }

    /**
     * @param value Path in Storage Target to which namespacePath points.
     */
    @JvmName("sftxsjdyisurpnid")
    public suspend fun targetPath(`value`: Output<String>) {
        this.targetPath = value
    }

    /**
     * @param value Namespace path on a cache for a Storage Target.
     */
    @JvmName("lfsacumpuvxdedqm")
    public suspend fun namespacePath(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.namespacePath = mapped
    }

    /**
     * @param value Name of the access policy applied to this junction.
     */
    @JvmName("xcamnxdcvjbdftks")
    public suspend fun nfsAccessPolicy(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.nfsAccessPolicy = mapped
    }

    /**
     * @param value NFS export where targetPath exists.
     */
    @JvmName("oufwlxqvullxisuy")
    public suspend fun nfsExport(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.nfsExport = mapped
    }

    /**
     * @param value Path in Storage Target to which namespacePath points.
     */
    @JvmName("qotxgieoomuvpiqn")
    public suspend fun targetPath(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.targetPath = mapped
    }

    internal fun build(): NamespaceJunctionArgs = NamespaceJunctionArgs(
        namespacePath = namespacePath,
        nfsAccessPolicy = nfsAccessPolicy,
        nfsExport = nfsExport,
        targetPath = targetPath,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/storagecache/kotlin/inputs/NamespaceJunctionArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.storagecache.kotlin.inputs

import com.pulumi.azurenative.storagecache.inputs.NamespaceJunctionArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * A namespace junction.
 * @property namespacePath Namespace path on a cache for a Storage Target.
 * @property nfsAccessPolicy Name of the access policy applied to this junction.
 * @property nfsExport NFS export where targetPath exists.
 * @property targetPath Path in Storage Target to which namespacePath points.
 */
public data class NamespaceJunctionArgs(
    public val namespacePath: Output<String>? = null,
    public val nfsAccessPolicy: Output<String>? = null,
    public val nfsExport: Output<String>? = null,
    public val targetPath: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.storagecache.inputs.NamespaceJunctionArgs> {
    override fun toJava(): com.pulumi.azurenative.storagecache.inputs.NamespaceJunctionArgs =
        com.pulumi.azurenative.storagecache.inputs.NamespaceJunctionArgs.builder()
            .namespacePath(namespacePath?.applyValue({ args0 -> args0 }))
            .nfsAccessPolicy(nfsAccessPolicy?.applyValue({ args0 -> args0 }))
            .nfsExport(nfsExport?.applyValue({ args0 -> args0 }))
            .targetPath(targetPath?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [NamespaceJunctionArgs].
 */
@PulumiTagMarker
public class NamespaceJunctionArgsBuilder internal constructor() {
    private var namespacePath: Output<String>? = null

    private var nfsAccessPolicy: Output<String>? = null

    private var nfsExport: Output<String>? = null

    private var targetPath: Output<String>? = null

    /**
     * @param value Namespace path on a cache for a Storage Target.
     */
    @JvmName("tromxjbapsnpmlnv")
    public suspend fun namespacePath(`value`: Output<String>) {
        this.namespacePath = value
    }

    /**
     * @param value Name of the access policy applied to this junction.
     */
    @JvmName("ymtjfkhgapjywmdw")
    public suspend fun nfsAccessPolicy(`value`: Output<String>) {
        this.nfsAccessPolicy = value
    }

    /**
     * @param value NFS export where targetPath exists.
     */
    @JvmName("amtpyevtglcglkwk")
    public suspend fun nfsExport(`value`: Output<String>) {
        this.nfsExport = value
    }

    /**
     * @param value Path in Storage Target to which namespacePath points.
     */
    @JvmName("wmeejkemwmiqdrdh")
    public suspend fun targetPath(`value`: Output<String>) {
        this.targetPath = value
    }

    /**
     * @param value Namespace path on a cache for a Storage Target.
     */
    @JvmName("qhlcplstrxmygmdo")
    public suspend fun namespacePath(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.namespacePath = mapped
    }

    /**
     * @param value Name of the access policy applied to this junction.
     */
    @JvmName("ipvbpdogqxispfok")
    public suspend fun nfsAccessPolicy(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.nfsAccessPolicy = mapped
    }

    /**
     * @param value NFS export where targetPath exists.
     */
    @JvmName("hcfdthaxtxracjcx")
    public suspend fun nfsExport(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.nfsExport = mapped
    }

    /**
     * @param value Path in Storage Target to which namespacePath points.
     */
    @JvmName("bauadrgmqdlgqhbw")
    public suspend fun targetPath(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.targetPath = mapped
    }

    internal fun build(): NamespaceJunctionArgs = NamespaceJunctionArgs(
        namespacePath = namespacePath,
        nfsAccessPolicy = nfsAccessPolicy,
        nfsExport = nfsExport,
        targetPath = targetPath,
    )
}
